// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef CANTOR_VERSION_H
#define CANTOR_VERSION_H

#define CANTOR_VERSION_STRING "26.04.1"
#define CANTOR_VERSION_MAJOR 26
#define CANTOR_VERSION_MINOR 4
#define CANTOR_VERSION_PATCH 1
#define CANTOR_VERSION ((26<<16)|(4<<8)|(1))

#endif
